@@ -1,6 +1,6 @@
 import asyncio
 import atexit
-import json
+import orjson
 import logging.config
 import platform
 import random
@@ -64,7 +64,7 @@ async def paginate(query: str, session: aiohttp.ClientSession, config: dict, out
         config['cursor'] = next_cursor
         data, next_cursor = await backoff(lambda: get(session, api, config), query)
         data['query'] = query
-        (out / f'raw/{time.time_ns()}.json').write_text(json.dumps(data, indent=4))
+        (out / f'raw/{time.time_ns()}.json').write_text(orjson.dumps(data, option=orjson.OPT_INDENT_2).decode())
         all_data.append(data)
     return all_data
 
@@ -136,10 +136,10 @@ def make_output_dirs(path: str) -> Path:
 @atexit.register
 def combine_results(in_path: Path = IN_PATH, out_path: Path = OUT_PATH):
     try:
-        out_path.write_text(json.dumps({
+        out_path.write_text(orjson.dumps({
             k: v
             for p in in_path.iterdir() if p.suffix == '.json'
-            for k, v in json.loads(p.read_text())['globalObjects']['tweets'].items()
-        }, indent=2))
+            for k, v in orjson.loads(p.read_text())['globalObjects']['tweets'].items()
+        }, option=orjson.OPT_INDENT_2).decode())
     except Exception as e:
         logger.debug(f'FAILED to combine search results, {e}')
